@@ -1,6 +1,6 @@
-#! /bin/bash
+#! /usr/bin/env bash
 # source: proxyecho.sh
-# Copyright Gerhard Rieger 2003
+# Copyright Gerhard Rieger and contributors (see file CHANGES)
 # Published under the GNU General Public License V.2, see file COPYING
 
 # perform primitive simulation of a proxy server with echo function via stdio.
@@ -56,4 +56,4 @@ echo "HTTP/1.0${SPACES}200 OK"
 echo
 
 # perform echo function
-$CAT
+exec $CAT
